@@ -27,6 +27,19 @@
   ok("$d"    eq '1');
   ok("$e,$f" eq '2,3');
 
+  The focii to locus round trip of an ellipse has a length of twice the
+  major radius:
+
+  use Math::Algebra::Symbols;
+  use Test::More tests => 1;
+  my ($R, $f, $x, $i) = symbols(qw(R f x i)); # Major radius, focii
+
+  my $y  = sqrt($R*$R-$f*$f - $x*$x +$f*$f*$x*$x / ($R*$R));  # Ellipse: rr=RR-ff
+  my $a = $x+$i*$y - $f;            # Vector from focus1 to a point on the locus
+  my $b = $x+$i*$y + $f;            # Vector from focus2 to same point on the locus
+
+  ok(abs($a) + abs($b) ==  2*$R, 'Focus trip is constant 2R');
+
   Floating point calculations on a triangle with angles of 22.5, 45, 112.5
   degrees to determine whether two of the diameters of the nine point circle
   are at right angles yield (on my computer) the following inconclusive result
@@ -65,8 +78,8 @@
 
 =head1 Description
 
-  This package supplies a set of functions and operators to manipulate
-  operator expressions algebraically using the familiar Perl syntax.
+  This package supplies a set of functions and operators to manipulate operator
+  expressions algebraically using the familiar Perl syntax.
 
   These expressions are constructed from L</Symbols>, L</Operators>, and
   L</Functions>, and processed via L</Methods>.  For examples, see:
@@ -86,10 +99,17 @@
   The B<symbols()> routine constructs references to symbolic variables and
   symbolic constants from a list of names and integer constants.
 
+  It is often useful to declare a variable B<$o> to contain the unit B<1> with
+  which to start symbolic expressions, thus:
+
+  $o/2 is a symbolic expression for one half where-as:
+
+  1/2 == 0.5 is merely the numeric representation of one half.
+
   The special symbol B<i> is recognized as the square root of B<-1>.
 
-  The special symbol B<pi> is recognized as the smallest positive real
-  that satisfies:
+  The special symbol B<pi> is recognized as the smallest positive real that
+  satisfies:
 
   use Math::Algebra::Symbols;
   use Test::Simple tests=>2;
@@ -220,9 +240,8 @@
   ok(  ($x**2-$y**2)/($x-$y)  !=  $x-$y  );
   ok(  ($x**2-$y**2)/($x-$y) <=> '$x+$y' );
 
-  The relational equality operator B<==> compares two symbolic expressions
-  and returns TRUE(1) or FALSE(0) accordingly. B<!=> produces the opposite
-  result.
+  The relational equality operator B<==> compares two symbolic expressions and
+  returns TRUE(1) or FALSE(0) accordingly. B<!=> produces the opposite result.
 
 =head4 Relational operator: B<eq>
 
@@ -250,13 +269,11 @@
   ok(  (($a+$i*$b)^($a-$i*$b))  !=  $a**2+$b**2  );
   ok(  (($a+$i*$b)^($a-$i*$b)) <=> '$a**2-$b**2' );
 
-
-
   Please note the use of brackets:  The B<^> operator has low priority.
 
-  The B<^> operator treats its left hand and right hand arguments as
-  complex numbers, which in turn are regarded as two dimensional vectors
-  to which the vector dot product is applied.
+  The B<^> operator treats its left hand and right hand arguments as complex
+  numbers, which in turn are regarded as two dimensional vectors to which the
+  vector dot product is applied.
 
 =head4 Complex operators: the B<cross> operator: B<x>
 
@@ -414,9 +431,8 @@
 
   ok( tanh($x+$y)==(tanh($x)+tanh($y))/(1+tanh($x)*tanh($y)));
 
-  The hyperbolic functions B<cosh>, B<sinh>, B<tanh>, B<sech>, B<csch>,
-  B<coth> are available, either as exports to the caller's name space, or
-  as methods.
+  The hyperbolic functions B<cosh>, B<sinh>, B<tanh>, B<sech>, B<csch>, B<coth>
+  are available, either as exports to the caller's name space, or as methods.
 
 =head3 Complex functions
 
@@ -673,7 +689,8 @@ Example t/simplify2.t
 =cut
 
 package Math::Algebra::Symbols;
-$VERSION=1.26;
+use strict;
+our $VERSION=1.27;
 use Math::Algebra::Symbols::Sum;
 use Carp;
 
@@ -822,7 +839,7 @@ END
 
 =item Variables
 
-  any number of variables raised to integer powers,
+  Any number of variables raised to integer powers.
 
 =item Coefficient
 
