@@ -1,4 +1,4 @@
-#!perl -w
+#!perl -w   -I/home/phil/z/Perl/cpanModules/Math-Algebra-Symbols/lib
 
 =head1 Sums
 
@@ -13,7 +13,8 @@ PhilipRBrenan@gmail.com, 2016, Perl License. www.appaapps.com
 
 
 package Math::Algebra::Symbols::Sum;
-$VERSION=1.26;
+use strict;
+our $VERSION=1.27;
 use Math::Algebra::Symbols::Term;
 use IO::Handle;
 use Carp;
@@ -36,6 +37,35 @@ sub new
  }
 
 
+=head3 constants
+
+Variables used to sign and lock each sum that have to be declared early on
+
+=cut
+
+
+my $lock = 0;   # Hash locking
+my $z = 0;      # Term counter
+my %z;          # Terms finalized
+
+=head3 constants
+
+Useful constants
+
+=cut
+
+my $zero  = &sigma(&term('0'));    sub zero()  {$zero}
+my $one   = &sigma(&term('1'));    sub one()   {$one}
+my $two   = &sigma(&term('2'));    sub two()   {$two}
+my $four  = &sigma(&term('4'));    sub four()  {$four}
+my $mOne  = &sigma(&term('-1'));   sub mOne()  {$mOne}
+my $i     = &sigma(&term('i'));    sub i()     {$i}
+my $mI    = &sigma(&term('-i'));   sub mI()    {$mI}
+my $half  = &sigma(&term('1/2'));  sub half()  {$half}
+my $mHalf = &sigma(&term('-1/2')); sub mHalf() {$mHalf}
+my $pi    = &sigma(&term('pi'));   sub pi()    {$pi}
+
+
 =head3 newFromString
 
 New from String
@@ -574,13 +604,23 @@ sub isEqualSqrt($)
 #_______________________________________________________________________
 
     my $ns = scalar(@t);
-    $ns < 5 or die "There are $ns square roots present.  I can handle less than 5";
+# 2016/01/26 12:29:28 No need to die
+#   $ns < 5 or die "There are $ns square roots present.  I can handle less than 5";
 
-    my ($a, $b, $c, $d) = @t;
+    my ($a, $b, $c, $d, $e) = @t;
 
     if    ($ns == 1)
      {$C = $a;
      }
+
+=pod
+       𝗮+𝗯        = 0
+ => a+b+2𝗮𝗯 = 0
+ => 2𝗮𝗯        = -a-b
+ => 0       =  aa+bb-2ab
+            = (a-b)**2 or (b-a)**2
+=cut
+
     elsif ($ns == 2)
      {$C = $a-$b;
      }
@@ -691,7 +731,7 @@ sub solve($$)
    }
   my $x = $x[0];
 
-  $B = $A->isZero;  # Eliminate sqrts and negative powers
+  my $B = $A->isZero;  # Eliminate sqrts and negative powers
 
 # Strike all terms with free variables other than x: i.e. not x and not one of the named constants
   my @t = ();
@@ -1499,11 +1539,6 @@ read only.
 
 =cut
 
-
-my $lock = 0;   # Hash locking
-my $z = 0;      # Term counter
-my %z;          # Terms finalized
-
 sub z($)
  {my ($t) = @_;
   !exists($t->{z}) or die "Already finalized this term";
@@ -1575,25 +1610,6 @@ sub print($)
  }
 
 
-=head3 constants
-
-Useful constants
-
-=cut
-
-
-$zero  = sigma(term('0'));    sub zero()  {$zero}
-$one   = sigma(term('1'));    sub one()   {$one}
-$two   = sigma(term('2'));    sub two()   {$two}
-$four  = sigma(term('4'));    sub four()  {$four}
-$mOne  = sigma(term('-1'));   sub mOne()  {$mOne}
-$i     = sigma(term('i'));    sub i()     {$i}
-$mI    = sigma(term('-i'));   sub mI()    {$mI}
-$half  = sigma(term('1/2'));  sub half()  {$half}
-$mHalf = sigma(term('-1/2')); sub mHalf() {$mHalf}
-$pi    = sigma(term('pi'));   sub pi()    {$pi}
-
-
 =head3 factorize
 
 Factorize a number.
@@ -1601,7 +1617,7 @@ Factorize a number.
 =cut
 
 
-@primes = qw(
+my @primes = qw(
   2  3   5   7   11  13  17  19  23  29  31  37  41  43  47  53  59  61
  67 71  73  79   83  89  97 101 103 107 109 113 127 131 137 139 149 151
 157 163 167 173 179 181 191 193 197 199 211 223 227 229 233 239 241 251
