@@ -13,7 +13,8 @@ PhilipRBrenan@gmail.com, 2016, Perl License. www.appaapps.com
 
 
 package Math::Algebra::Symbols::Term;
-$VERSION=1.26;
+use strict;
+our $VERSION=1.27;
 use Carp;
 use Math::BigInt;
 #HashUtil use Hash::Util qw(lock_hash);
@@ -35,6 +36,35 @@ sub new
  }
 
 
+=head3 Finalization
+
+Sign and lock terms
+
+=cut
+
+my $lock = 0;   # Hash locking
+my $z = 0;      # Term counter
+my %z;          # Terms finalized
+
+
+=head3 constants
+
+Useful constants
+
+=cut
+
+
+my $zero  = new()->c(0)->z;           sub zero () {$zero}
+my $one   = new()->z;                 sub one  () {$one}
+my $two   = new()->c(2)->z;           sub two  () {$two}
+my $mOne  = new()->c(-1)->z;          sub mOne () {$mOne}
+my $i     = new()->i(1)->z;           #sub pI   () {$pI}
+my $mI    = new()->c(-1)->i(1)->z;    sub mI   () {$mI}
+my $half  = new()->c( 1)->d(2)->z;    sub half () {$half}
+my $mHalf = new()->c(-1)->d(2)->z;    sub mHalf() {$mHalf}
+my $pi    = new()->vp('pi', 1)->z;    sub pi   () {$pi}
+
+
 =head3 newFromString
 
 New from String
@@ -939,9 +969,9 @@ sub sin2($)
   return $half  if $c ==  5;
   return $zero  if $c ==  6;
   return $mHalf if $c ==  7;
-  return $undef if $c ==  8;
+  return undef  if $c ==  8;
   return $mOne  if $c ==  9;
-  return $undef if $c == 10;
+  return undef  if $c == 10;
   return $mHalf if $c == 11;
   return $zero  if $c == 12;
  }
@@ -978,16 +1008,16 @@ sub cos2($)
   $c = $c % 12;
 
   return $half  if $c == 10;
-  return $undef if $c == 11;
+  return undef  if $c == 11;
   return $one   if $c == 12;
   return $one   if $c ==  0;
   return undef  if $c ==  1;
   return $half  if $c ==  2;
   return $zero  if $c ==  3;
   return $mHalf if $c ==  4;
-  return $undef if $c ==  5;
+  return undef  if $c ==  5;
   return $mOne  if $c ==  6;
-  return $undef if $c ==  7;
+  return undef  if $c ==  7;
   return $mHalf if $c ==  8;
   return $zero  if $c ==  9;
  }
@@ -1041,15 +1071,11 @@ sub zz($)
 =head3 z
 
 Finalize creation of the term. Once a term has been finalized, it
-becomes readonly, which allows optimization to be performed. =cut
+becomes readonly, which allows optimization to be performed.
 
 =cut
 
 
-my $lock = 0;   # Hash locking
-my $z = 0;      # Term counter
-my %z;          # Terms finalized
-
 sub z($)
  {my ($t) = @_;
   !exists($t->{z}) or die "Already finalized this term";
@@ -1111,24 +1137,6 @@ sub print($)
  }
 
 
-=head3 constants
-
-Useful constants
-
-=cut
-
-
-$zero  = new()->c(0)->z;           sub zero () {$zero}
-$one   = new()->z;                 sub one  () {$one}
-$two   = new()->c(2)->z;           sub two  () {$two}
-$mOne  = new()->c(-1)->z;          sub mOne () {$mOne}
-$i     = new()->i(1)->z;           sub pI   () {$pI}
-$mI    = new()->c(-1)->i(1)->z;    sub mI   () {$mI}
-$half  = new()->c( 1)->d(2)->z;    sub half () {$half}
-$mHalf = new()->c(-1)->d(2)->z;    sub mHalf() {$mHalf}
-$pi    = new()->vp('pi', 1)->z;    sub pi   () {$pi}
-
-
 =head2 import
 
 Export L</newFromStrings> to calling package with a name specifed by the
@@ -1405,7 +1413,7 @@ Tests
 
 
 sub test()
- {my ($a, $b, $c);
+ {my ($a, $b, $c, $d);
 # lockHashes();
   $a = n(0);                $a == $zero                 or die "100";
   $a = n(1);                $a == $one                  or die "101";
